Index: trunk/MagicSoft/Mars/manalysis/MCT1PadONOFF.cc
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MCT1PadONOFF.cc	(revision 2797)
+++ trunk/MagicSoft/Mars/manalysis/MCT1PadONOFF.cc	(revision 2798)
@@ -85,6 +85,7 @@
 #include "MCerPhotEvt.h"
 
-#include "MPedestalCam.h"
-#include "MPedestalPix.h"
+#include "MPedPhotCam.h"
+#include "MPedPhotPix.h"
+
 #include "MBlindPixels.h"
 
@@ -910,8 +911,8 @@
      }
   
-   fPed = (MPedestalCam*)pList->FindObject("MPedestalCam");
+   fPed = (MPedPhotCam*)pList->FindObject("MPedPhotCam");
    if (!fPed)
      {
-       *fLog << err << "MPedestalCam not found... aborting." << endl;
+       *fLog << err << "MPedPhotCam not found... aborting." << endl;
        return kFALSE;
      }
@@ -1014,5 +1015,5 @@
       continue;
 
-    fEvt->AddPixel(i, 0.0, (*fPed)[i].GetPedestalRms());
+    fEvt->AddPixel(i, 0.0, (*fPed)[i].GetRms());
   }
 
@@ -1038,6 +1039,6 @@
   //  Int_t j = pix.GetPixId();
 
-  //  MPedestalPix &ppix = fPed->operator[](j);
-  //  ppix.SetMeanRms(0.0);
+  //  MPedPhotPix &ppix = fPed->operator[](j);
+  //  ppix.SetRms(0.0);
   //}
   //$$$$$$$$$$$$$$$$$$$$$$$$$$
@@ -1404,6 +1405,6 @@
     Double_t ratioArea = 1.0 / fCam->GetPixRatio(j);
 
-    MPedestalPix &ppix = (*fPed)[j];
-    Double_t oldsigma = ppix.GetPedestalRms();
+    MPedPhotPix &ppix = (*fPed)[j];
+    Double_t oldsigma = ppix.GetRms();
     Double_t oldsigma2 = oldsigma*oldsigma;
 
@@ -1602,5 +1603,5 @@
 
     Double_t newsigma = sqrt( oldsigma2 + addSig2 ); 
-    ppix.SetPedestalRms( newsigma );
+    ppix.SetRms( newsigma );
 
     fHSigmaPedestal->Fill( oldsigma, newsigma );
Index: trunk/MagicSoft/Mars/manalysis/MCT1PadONOFF.h
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MCT1PadONOFF.h	(revision 2797)
+++ trunk/MagicSoft/Mars/manalysis/MCT1PadONOFF.h	(revision 2798)
@@ -16,5 +16,5 @@
 class MGeomCam;
 class MCerPhotEvt;
-class MPedestalCam;
+class MPedPhotCam;
 class MMcEvt;
 class MSigmabar;
@@ -32,5 +32,5 @@
     MSigmabar      *fSigmabar;
     MMcEvt         *fMcEvt;
-    MPedestalCam   *fPed;
+    MPedPhotCam   *fPed;
     MBlindPixels   *fBlinds;
 
Index: trunk/MagicSoft/Mars/manalysis/MCT1PadSchweizer.cc
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MCT1PadSchweizer.cc	(revision 2797)
+++ trunk/MagicSoft/Mars/manalysis/MCT1PadSchweizer.cc	(revision 2798)
@@ -84,6 +84,7 @@
 #include "MCerPhotEvt.h"
 
-#include "MPedestalCam.h"
-#include "MPedestalPix.h"
+#include "MPedPhotCam.h"
+#include "MPedPhotPix.h"
+
 #include "MBlindPixels.h"
 
@@ -197,8 +198,8 @@
      }
   
-   fPed = (MPedestalCam*)pList->FindObject("MPedestalCam");
+   fPed = (MPedPhotCam*)pList->FindObject("MPedPhotCam");
    if (!fPed)
      {
-       *fLog << err << "MPedestalCam not found... aborting." << endl;
+       *fLog << err << "MPedPhotCam not found... aborting." << endl;
        return kFALSE;
      }
@@ -293,5 +294,5 @@
       continue;
 
-    fEvt->AddPixel(i, 0.0, (*fPed)[i].GetPedestalRms());
+    fEvt->AddPixel(i, 0.0, (*fPed)[i].GetRms());
   }
 
@@ -316,6 +317,6 @@
   //  Int_t j = pix.GetPixId();
 
-  //  MPedestalPix &ppix = fPed->operator[](j);
-  //  ppix.SetMeanRms(0.0);
+  //  MPedPhotPix &ppix = fPed->operator[](j);
+  //  ppix.SetRms(0.0);
   //}
   //$$$$$$$$$$$$$$$$$$$$$$$$$$
@@ -543,6 +544,6 @@
     Double_t ratioArea = 1.0 / fCam->GetPixRatio(j);
 
-    MPedestalPix &ppix = (*fPed)[j];
-    Double_t oldsigma = ppix.GetPedestalRms();
+    MPedPhotPix &ppix = (*fPed)[j];
+    Double_t oldsigma = ppix.GetRms();
     Double_t oldsigma2 = oldsigma*oldsigma;
 
@@ -706,5 +707,5 @@
 
     Double_t newsigma = sqrt(oldsigma2 + addSig2);
-    ppix.SetPedestalRms(newsigma);
+    ppix.SetRms(newsigma);
 
     fHSigmaPedestal->Fill(oldsigma, newsigma);
Index: trunk/MagicSoft/Mars/manalysis/MCT1PadSchweizer.h
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MCT1PadSchweizer.h	(revision 2797)
+++ trunk/MagicSoft/Mars/manalysis/MCT1PadSchweizer.h	(revision 2798)
@@ -16,5 +16,5 @@
 class MGeomCam;
 class MCerPhotEvt;
-class MPedestalCam;
+class MPedPhotCam;
 class MMcEvt;
 class MSigmabar;
@@ -29,5 +29,5 @@
     MSigmabar      *fSigmabar;
     MMcEvt         *fMcEvt;
-    MPedestalCam   *fPed;
+    MPedPhotCam   *fPed;
     MBlindPixels   *fBlinds;
 
Index: trunk/MagicSoft/Mars/manalysis/MPad.h
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MPad.h	(revision 2797)
+++ trunk/MagicSoft/Mars/manalysis/MPad.h	(revision 2798)
@@ -16,5 +16,5 @@
 class MGeomCam;
 class MCerPhotEvt;
-class MPedestalCam;
+class MPedPhotCam;
 class MMcEvt;
 class MSigmabar;
@@ -32,5 +32,5 @@
     MSigmabar      *fSigmabar;
     MMcEvt         *fMcEvt;
-    MPedestalCam   *fPed;
+    MPedPhotCam    *fPed;
     MBlindPixels   *fBlinds;
 
Index: trunk/MagicSoft/Mars/manalysis/MPadding.cc
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MPadding.cc	(revision 2797)
+++ trunk/MagicSoft/Mars/manalysis/MPadding.cc	(revision 2798)
@@ -93,6 +93,6 @@
 #include "MCerPhotPix.h"
 
-#include "MPedestalCam.h"
-#include "MPedestalPix.h"
+#include "MPedPhotCam.h"
+#include "MPedPhotPix.h"
 
 ClassImp(MPadding);
@@ -239,8 +239,8 @@
      }
   
-   fPed = (MPedestalCam*)pList->FindObject("MPedestalCam");
+   fPed = (MPedPhotCam*)pList->FindObject("MPedPhotCam");
    if (!fPed)
      {
-       *fLog << err << dbginf << "MPedestalCam not found... aborting." << endl;
+       *fLog << err << dbginf << "MPedPhotCam not found... aborting." << endl;
        return kFALSE;
      }
@@ -443,11 +443,11 @@
      pix.SetErrorPhot( newerror );
 
-     MPedestalPix &ppix = (*fPed)[i];
-
-     ppix.SetMeanRms(0);
-
-     const Double_t oldsigma = ppix.GetMeanRms();
+     MPedPhotPix &ppix = (*fPed)[i];
+
+     ppix.SetRms(0);
+
+     const Double_t oldsigma = ppix.GetRms();
      const Double_t newsigma = sqrt( oldsigma*oldsigma + quadraticDiff*area );
-     ppix.SetMeanRms( newsigma );
+     ppix.SetRms( newsigma );
 
      fHSigmaPedestal->Fill( oldsigma, newsigma );
Index: trunk/MagicSoft/Mars/manalysis/MPadding.h
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MPadding.h	(revision 2797)
+++ trunk/MagicSoft/Mars/manalysis/MPadding.h	(revision 2798)
@@ -10,7 +10,6 @@
 class MGeomCam;
 class MCerPhotEvt;
-class MPedestalCam;
+class MPedPhotCam;
 class MMcEvt;
-class MPedestalCam;
 class MSigmabar;
 class MParList;
@@ -23,5 +22,5 @@
     MSigmabar    *fSigmabar;
     MMcEvt       *fMcEvt;
-    MPedestalCam *fPed;
+    MPedPhotCam  *fPed;
 
     Int_t     fRunType;
Index: trunk/MagicSoft/Mars/manalysis/MPedPhotPix.h
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MPedPhotPix.h	(revision 2797)
+++ trunk/MagicSoft/Mars/manalysis/MPedPhotPix.h	(revision 2798)
@@ -21,5 +21,5 @@
 
     //void SetMean(Float_t f) { fMean = f; }
-    //void SetRms(Float_t f)  { fRms  = f; }
+    void SetRms(Float_t f)  { fRms  = f; }
     void Set(Float_t m, Float_t r) { fMean = m; fRms = r; }
 
Index: trunk/MagicSoft/Mars/manalysis/MSigmabar.cc
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MSigmabar.cc	(revision 2797)
+++ trunk/MagicSoft/Mars/manalysis/MSigmabar.cc	(revision 2798)
@@ -50,6 +50,6 @@
 #include "MCerPhotPix.h"
 
-#include "MPedestalCam.h"
-#include "MPedestalPix.h"
+#include "MPedPhotCam.h"
+#include "MPedPhotPix.h"
 
 ClassImp(MSigmabar);
@@ -95,5 +95,5 @@
 // determination of sector to which a respective pixel belongs
 //
-Float_t MSigmabar::Calc(const MGeomCam &geom, const MPedestalCam &ped, 
+Float_t MSigmabar::Calc(const MGeomCam &geom, const MPedPhotCam &ped, 
                         const MCerPhotEvt &evt)
 {
@@ -154,5 +154,5 @@
 
         // count only those pixels which have a sigma != 0.0
-        const Float_t sigma = ped[idx].GetPedestalRms();
+        const Float_t sigma = ped[idx].GetRms();
 
         if ( sigma <= 0 )
Index: trunk/MagicSoft/Mars/manalysis/MSigmabar.h
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MSigmabar.h	(revision 2797)
+++ trunk/MagicSoft/Mars/manalysis/MSigmabar.h	(revision 2798)
@@ -9,5 +9,5 @@
 class MParList;
 class MCerPhotEvt;
-class MPedestalCam;
+class MPedPhotCam;
 
 class MSigmabar : public MParContainer
@@ -44,5 +44,5 @@
     //    void SetSigmabarOuter(Float_t f) { fSigmabarOuter = f; }   
 
-    Float_t Calc(const MGeomCam &geom, const MPedestalCam &ped, const MCerPhotEvt &evt);
+    Float_t Calc(const MGeomCam &geom, const MPedPhotCam &ped, const MCerPhotEvt &evt);
       
     ClassDef(MSigmabar, 1)  // Storage Container for Sigmabar
Index: trunk/MagicSoft/Mars/manalysis/MSigmabarCalc.cc
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MSigmabarCalc.cc	(revision 2797)
+++ trunk/MagicSoft/Mars/manalysis/MSigmabarCalc.cc	(revision 2798)
@@ -35,5 +35,5 @@
 //  Input Containers:
 //   MGeomCam
-//   MPedestalCam
+//   MPedPhotCam
 //   MRawRunHeader
 //   MMcEvt  (FIXME: Must be replaced by a 'real-data' container)
@@ -53,5 +53,5 @@
 
 #include "MGeomCam.h"
-#include "MPedestalCam.h"
+#include "MPedPhotCam.h"
 
 #include "MSigmabar.h"
@@ -90,8 +90,8 @@
     }
 
-    fPed = (MPedestalCam*)pList->FindObject(AddSerialNumber("MPedestalCam"));
+    fPed = (MPedPhotCam*)pList->FindObject(AddSerialNumber("MPedPhotCam"));
     if (!fPed)
     {
-        *fLog << err << "MPedestalCam not found... aborting." << endl;
+        *fLog << err << "MPedPhotCam not found... aborting." << endl;
         return kFALSE;
     }
Index: trunk/MagicSoft/Mars/manalysis/MSigmabarCalc.h
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MSigmabarCalc.h	(revision 2797)
+++ trunk/MagicSoft/Mars/manalysis/MSigmabarCalc.h	(revision 2798)
@@ -14,6 +14,6 @@
 #endif
 
-#ifndef MARS_MPedestalCam
-#include "MPedestalCam.h"
+#ifndef MARS_MPedPhotCam
+#include "MPedPhotCam.h"
 #endif
 
@@ -36,5 +36,5 @@
     MCerPhotEvt    *fEvt;
     MGeomCam       *fCam;
-    MPedestalCam   *fPed;
+    MPedPhotCam   *fPed;
     MRawRunHeader  *fRun;
     MSigmabar      *fSig;

Index: trunk/MagicSoft/Mars/manalysis/MPad.cc
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MPad.cc	(revision 2797)
+++ trunk/MagicSoft/Mars/manalysis/MPad.cc	(revision 2798)
@@ -76,6 +76,7 @@
 #include "MCerPhotEvt.h"
 
-#include "MPedestalCam.h"
-#include "MPedestalPix.h"
+#include "MPedPhotCam.h"
+#include "MPedPhotPix.h"
+
 #include "MBlindPixels.h"
 
@@ -1477,8 +1478,8 @@
      }
   
-   fPed = (MPedestalCam*)pList->FindObject("MPedestalCam");
+   fPed = (MPedPhotCam*)pList->FindObject("MPedPhotCam");
    if (!fPed)
      {
        *fLog << err << "MPad : MPedestalCam not found... aborting." 
              << endl;
        return kFALSE;
@@ -1600,5 +1601,5 @@
       continue;
 
-    fEvt->AddPixel(i, 0.0, (*fPed)[i].GetPedestalRms());
+    fEvt->AddPixel(i, 0.0, (*fPed)[i].GetRms());
   }
 
@@ -1989,6 +1990,6 @@
     Double_t ratioArea = 1.0 / fCam->GetPixRatio(j);
 
-    MPedestalPix &ppix = (*fPed)[j];
-    Double_t oldsigma_phot = ppix.GetPedestalRms();
+    MPedPhotPix &ppix = (*fPed)[j];
+    Double_t oldsigma_phot = ppix.GetRms();
     Double_t oldsigma = oldsigma_phot * fPEperPhoton;
     Double_t oldsigma2 = oldsigma*oldsigma;
@@ -2140,5 +2141,5 @@
     Double_t newsigma = sqrt( oldsigma2 + addSig2 ); 
     Double_t newsigma_phot = newsigma / fPEperPhoton; 
-    ppix.SetPedestalRms( newsigma_phot );
+    ppix.SetRms( newsigma_phot );
 
     fHSigmaPedestal->Fill( oldsigma_phot, newsigma_phot );
@@ -1477,8 +1478,8 @@
    if (!fPed)
      {
-       *fLog << err << "MPad : MPedestalCam not found... aborting." 
+       *fLog << err << "MPad : MPedPhotCam not found... aborting." 
              << endl;
        return kFALSE;